#
# spec file for package ffmpegthumbnailer
#
# Copyright (c) 2014 Mariusz Fik <fisiu@opensuse.org>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define soname  4
Name:           ffmpegthumbnailer
Version:        2.2.0
Release:        4.10
Summary:        Video thumbnailer that can be used by file managers
License:        GPL-2.0+
Group:          Productivity/Graphics/Viewers
Url:            https://github.com/dirkvdb/ffmpegthumbnailer
Source:         https://github.com/dirkvdb/%{name}/releases/download/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This video thumbnailer can be used to create thumbnails for
video files. The thumbnailer uses ffmpeg to decode frames from the
video files, so supported video formats depend on the configuration
flags of ffmpeg.

The project also includes a C/C++ library that can be used by
developers to generate thumbnails in their projects.

%package -n lib%{name}%{soname}
Summary:        Video thumbnail generator
Group:          System/Libraries

%description -n lib%{name}%{soname}
Video thumbnailer that can be used by file managers.

This video thumbnailer can be used to create thumbnails for video
files. The thumbnailer uses ffmpeg to decode frames from files.

%package -n lib%{name}-devel
Summary:        Development files for ffmpegthumbnailer
Group:          Development/Languages/C and C++
Requires:       libffmpegthumbnailer%{soname} = %{version}

%description -n lib%{name}-devel
Video thumbnailer that can be used by file managers.

This video thumbnailer can be used to create thumbnails for video
files. The thumbnailer uses ffmpeg to decode frames from files.

%prep
%setup -q
chmod 644 AUTHORS README

%build
%cmake \
  -DCMAKE_BUILD_TYPE=Release \
  -DENABLE_GIO=ON \
  -DENABLE_THUMBNAILER=ON
%make_jobs

%install
%cmake_install

%post -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_mandir}/man1/*.1%{ext_man}
%{_bindir}/%{name}
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}.thumbnailer

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.%{soname}
%{_libdir}/lib%{name}.so.%{soname}.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_libdir}/lib%{name}.so
%dir %{_includedir}/lib%{name}
%{_includedir}/lib%{name}/*.h
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Fri May 26 2017 jengelh@inai.de
- Trim filler wording from description.
* Tue Nov 29 2016 fisiu@opensuse.org
- Update to 2.2.0, changes since 2.0.9 includes:
  * Option to prefer embedded image metadata over video content
  * Fixed 'Resource temporarily unavailable' errors when using ffmpeg < 3.0
  * Take rotation metadata into account when generating thumbnails
  * Additional video mime types added to the thumbnailer file
  * Add MPEG-TS (MTS) support
  * Project is hosted on github now
  * Use cmake instead of autotools
  * Many other fixes and minor improvements
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Fri Nov 21 2014 fisiu@opensuse.org
- Update to 2.0.9:
  * Fixed gio library loading
  * Support udp sources
  * No longer support older ffmpeg versions
- Drop ffmpegthumbnailer-glibc.patch: fixed upstream.
* Thu Nov 20 2014 joerg.lorenzen@ki.tng.de
- enable thumbnailer support (--enable-thumbnailer)
* Sat Nov  2 2013 joerg.lorenzen@ki.tng.de
- added patch to build against new glibc
* Sat Nov 10 2012 i@margueirte.su
- build against ffmpeg new API.
* Sun Oct 28 2012 pascal.bleser@opensuse.org
- update to 2.0.8
* Mon Oct 17 2011 pascal.bleser@opensuse.org
- update to 2.0.7
* Wed Mar  2 2011 pascal.bleser@opensuse.org
- update to 2.0.6:
  * fixes memory leaks
* Mon Dec 13 2010 pascal.bleser@opensuse.org
- update to 2.0.5:
  * replaced deprecate gnome-vfs with gio (--enable-gio)
* Sun Aug 15 2010 toni@links2linux.de
- update to 2.0.4
- Fixed undefined references when compiling with certain LDFLAGS
- Writing to stdout is now supported
- Support for gnome-vfs uris added. New configure flag (--enable-gnome-vfs),
  this puts a runtime dependancy on libgnome-vfs-2.0
* Tue Jul 20 2010 pascal.bleser@opensuse.org
- update to 2.0.2
* Tue Apr 27 2010 toni@links2linux.de
- update to 2.0.1
  * Setting the thumbnail size to 0 will use the original video size (thanks to John Fremlin)
  * Fix for video files containing lots of audio packets before a video packet
  * Fixed libs in pkgconfig file (thanks to magnus.tuominen)
* Sat Jan  9 2010 toni@links2linux.de
- update to 2.0.0
- new SOname ==> libffmpegthumbnailer4
* Fri Dec 25 2009 toni@links2linux.de
- update to 1.5.6
* Tue Sep 22 2009 Manfred.Tremmel@iiv.de
- update to 1.5.5
* Mon Jun 22 2009 toni@links2linux.de
- update to 1.5.4
* Mon Jun 15 2009 toni@links2linux.de
- update to 1.5.3
* Sun May 24 2009 toni@links2linux.de
- update to 1.5.2
- new SO-Name ==> libffmpegthumbnailer3
* Fri May 15 2009 toni@links2linux.de
- initial package 1.5.1
